@@ -8,7 +8,7 @@
 #             Handles bzr overlays
 #
 # Copyright:
-#             (c) 2005 - 2006 Adrian Perez, Gunnar Wrobel
+#             (c) 2005 - 2008 Adrian Perez, Gunnar Wrobel
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
@@ -42,7 +42,7 @@ class BzrOverlay(Overlay):
 
     binary_command  = '/usr/bin/bzr'
 
-    def add(self, base):
+    def add(self, base, quiet = False):
         '''Add overlay.'''
 
         self.supported()
@@ -50,7 +50,7 @@ class BzrOverlay(Overlay):
         return self.cmd(self.binary_command + ' get "' + self.src + '/" "' +\
                         path([base, self.name]) + '"')
 
-    def sync(self, base):
+    def sync(self, base, quiet = False):
         '''Sync overlay.'''
 
         self.supported()
